'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var http = require('@angular/common/http');
var rxjs = require('rxjs');
var operators = require('rxjs/operators');

// thaw-http-json-client-angular/src/main.ts
const httpOptions = {
    headers: new http.HttpHeaders({
        'Content-Type': 'application/json'
        // , 'Authorization': 'my-auth-token'
    })
};
class HttpClientBase {
    f(method, url, g) {
        return () => g().pipe(
        // retry(3), // retry a failed request up to 3 times
        operators.catchError((error) => this.handleError(method, url, error)));
    }
    // public makeIntentionalError() {
    // 	return this.get('not/a/real/url');
    // 	// const url = 'not/a/real/url';
    // 	// return this.http.get(url)
    // 	// 	.pipe(
    // 	// 		// catchError(this.handleError)
    // 	// 		catchError((error: HttpErrorResponse) => this.handleError('GET', url, error))
    // 	// 	);
    // }
    handleError(httpMethod, url, error) {
        console.error('handleError() : error is', error);
        // if (!error || error.ok !== false) {
        if (!error) {
            // return throwError({
            // 	error: {error}, // Angular lint seems to prefer this to: error: error,
            // 	message: 'Default: Error caught in HttpJsonClientService.handleError()'
            // });
            // return throwError(new HttpJsonClientError());
            return rxjs.throwError({});
        }
        if (error.error instanceof ErrorEvent) {
            // A client-side or network error occurred. Handle it accordingly.
            console.error('instanceof ErrorEvent. An error occurred:', error.error.message);
        }
        else {
            // The backend returned an unsuccessful response code.
            // The response body may contain clues as to what went wrong,
            console.error(`Not instanceof ErrorEvent. Backend returned code ${error.status}, body was:`, error.error);
        }
        // // return an ErrorObservable with a user-facing error message
        // // return new ErrorObservable('Something bad happened; please try again later.');
        // return throwError('Something bad happened; please try again later.');
        console.error(`${httpMethod} ${url} status: ${error.status} ${error.statusText}`);
        return rxjs.throwError({
            ok: typeof error.ok === 'boolean' ? error.ok : undefined,
            status: parseInt(error.status.toString(), 10) === error.status &&
                !Number.isNaN(error.status)
                ? error.status
                : undefined,
            statusText: error.statusText || undefined,
            message: error.message || undefined,
            url: error.url || undefined
        });
    }
}
class HttpSimpleClient extends HttpClientBase {
    constructor(http) {
        super();
        this.http = http;
    }
    get(url) {
        return this.f('GET', url, () => this.http.get(url, { responseType: 'text' }))();
    }
}
class HttpJsonClient extends HttpClientBase {
    constructor(http) {
        super();
        this.http = http;
    }
    get(url) {
        return this.f('GET', url, () => this.http.get(url))();
    }
    // public getHttpResponse<T>(url: string): Observable<HttpResponse<T>> {
    // 	return this.f('GET', url, () =>
    // 		this.http.get<T>(url, { observe: 'response' })
    // 	)();
    // }
    post(url, body) {
        return this.f('POST', url, () => this.http.post(url, body, httpOptions))();
    }
    put(url, body) {
        return this.f('PUT', url, () => this.http.put(url, body, httpOptions))();
    }
    patch(url, body) {
        return this.f('PATCH', url, () => this.http.patch(url, body, httpOptions))();
    }
    delete(url) {
        return this.f('DELETE', url, () => this.http.delete(url))();
    }
    head(url) {
        return this.f('HEAD', url, () => this.http.head(url))();
    }
    options(url) {
        return this.f('OPTIONS', url, () => this.http.options(url))();
    }
}
function createHttpClient(http) {
    return new HttpSimpleClient(http);
}
function createHttpJsonClient(http) {
    return new HttpJsonClient(http);
}

exports.createHttpClient = createHttpClient;
exports.createHttpJsonClient = createHttpJsonClient;
